@@ -17,17 +17,49 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Classes and app to compute satellite visibility';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db } ];
+}
+
+sub author {
+    return 'Tom Wyant (wyant at cpan dot org)';
+}
+
 sub build_requires {
     return +{
 	'Test::More'	=> 0.88,	# Because of done_testing().
+	lib		=> 0,
     };
 }
 
+sub configure_requires {
+    return +{
+	'Config'	=> 0,
+	'FileHandle'	=> 0,
+	'Getopt::Std'	=> 0,
+	'lib'	=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Astro-satpass';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
     my ( undef, @extra ) = @_;
     return {
@@ -40,7 +72,8 @@ sub meta_merge {
 	},
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://github.com/trwyant/perl-Astro-Coord-ECI/issues',
+		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass',
+		# web	=> 'https://github.com/trwyant/perl-Astro-Coord-ECI/issues',
                 mailto  => 'wyant@cpan.org',
 	    },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -54,6 +87,20 @@ sub meta_merge {
     };
 }
 
+sub module_name {
+    return 'Astro::Coord::ECI';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
 sub provides {
     -d 'lib'
 	or return;
@@ -77,10 +124,12 @@ sub requires {
 	'POSIX'		=> 0,
 	'Scalar::Util'	=> 1.22,	# For looks_like_number
 	'Storable'	=> 0,
-	'base'		=> 0,
-	'constant'	=> 0,
-	'strict'	=> 0,
-	'warnings'	=> 0,
+	'Time::Local'	=> 0,
+	base		=> 0,
+	constant	=> 0,
+	if		=> 0,
+	strict		=> 0,
+	warnings	=> 0,
 	@extra,
     };
 }
@@ -89,6 +138,15 @@ sub requires_perl {
     return 5.006002;
 }
 
+sub script_files {
+    return [
+	'script/satpass',
+    ];
+}
+
+sub version_from {
+    return 'lib/Astro/Coord/ECI.pm';
+}
 
 1;
 
@@ -123,6 +181,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -133,6 +204,20 @@ modules required to build the C<My::Module> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> key.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -144,6 +229,10 @@ C<< {META_MERGE}->{build_requires} >> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -156,6 +245,16 @@ C<resources> data.
 
 Any arguments will be appended to the generated array.
 
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
 =head2 provides
 
  use YAML;
@@ -185,11 +284,20 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
 
-
 =head1 ENVIRONMENT
 
 =head2 MAKING_MODULE_DISTRIBUTION
@@ -198,10 +306,10 @@ This environment variable should be set to a true value if you are
 making a distribution. This ensures that no configuration-specific
 information makes it into F<META.yml>.
 
-
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
 L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
 electronic mail to the author.
 
